*Rsstail*
----------

*Rsstail* is a command-line syndication feed monitor with behaviour
similar to ``tail -f``. *Rsstail* (Python/feedparser_) is inspired by
rsstail_ (C/libmrss_), but provides more customizable output
formatting and additional features.

Documentation:
    http://python-rsstail.readthedocs.org/en/latest/

Development:
    https://github.com/gvalkov/rsstail.py

Package:
    http://pypi.python.org/pypi/rsstail

.. _rsstail:    http://www.vanheusden.com/rsstail/
.. _feedstail:  http://pypi.python.org/pypi/feedstail/
.. _libmrss:    http://www.autistici.org/bakunin/libmrss/doc/
.. _feedparser: https://pypi.python.org/pypi/feedparser
